aboutsummaryrefslogtreecommitdiffstats
path: root/src/ooxml/java/org/apache/poi/xslf/usermodel/XSLFTableStyle.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/ooxml/java/org/apache/poi/xslf/usermodel/XSLFTableStyle.java')
-rw-r--r--src/ooxml/java/org/apache/poi/xslf/usermodel/XSLFTableStyle.java44
1 files changed, 41 insertions, 3 deletions
diff --git a/src/ooxml/java/org/apache/poi/xslf/usermodel/XSLFTableStyle.java b/src/ooxml/java/org/apache/poi/xslf/usermodel/XSLFTableStyle.java
index 31840314b9..b3bcdfabd9 100644
--- a/src/ooxml/java/org/apache/poi/xslf/usermodel/XSLFTableStyle.java
+++ b/src/ooxml/java/org/apache/poi/xslf/usermodel/XSLFTableStyle.java
@@ -19,16 +19,19 @@
package org.apache.poi.xslf.usermodel;
+import org.openxmlformats.schemas.drawingml.x2006.main.CTTablePartStyle;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTableStyle;
/**
* Represents a table in a .pptx presentation
*
* @author Yegor Kozlov
*/
public class XSLFTableStyle {
private CTTableStyle _tblStyle;
+ public enum TablePartStyle {
+ wholeTbl, band1H, band2H, band1V, band2V, firstCol, lastCol, firstRow, lastRow, seCell, swCell, neCell, nwCell;
+ }
+
/*package*/ XSLFTableStyle(CTTableStyle style){
_tblStyle = style;
}
@@ -44,4 +47,39 @@ public class XSLFTableStyle {
public String getStyleId(){
return _tblStyle.getStyleId();
}
+
+ /**
+ * @since POI 3.15-beta2
+ */
+ protected CTTablePartStyle getTablePartStyle(TablePartStyle tps) {
+ switch (tps) {
+ default:
+ case wholeTbl:
+ return _tblStyle.getWholeTbl();
+ case band1H:
+ return _tblStyle.getBand1H();
+ case band2H:
+ return _tblStyle.getBand2H();
+ case band1V:
+ return _tblStyle.getBand1V();
+ case band2V:
+ return _tblStyle.getBand2V();
+ case firstCol:
+ return _tblStyle.getFirstCol();
+ case lastCol:
+ return _tblStyle.getLastCol();
+ case firstRow:
+ return _tblStyle.getFirstRow();
+ case lastRow:
+ return _tblStyle.getLastRow();
+ case seCell:
+ return _tblStyle.getSeCell();
+ case swCell:
+ return _tblStyle.getSwCell();
+ case neCell:
+ return _tblStyle.getNeCell();
+ case nwCell:
+ return _tblStyle.getNwCell();
+ }
+ }
} \ No newline at end of file
@@ -19,16 +19,19 @@
import org.openxmlformats.schemas.drawingml.x2006.main.CTTableStyle;
/**
- * Represents a table in a .pptx presentation
- *
- * @author Yegor Kozlov
+ * Represents a table style in a .pptx presentation
*/
public class XSLFTableStyle {